#[non_exhaustive]pub enum AccessPolicy {
ReadWrite,
ReadOnly,
}Expand description
Access policy granted to an accepted client.
The reflector uses this value to gate whether inbound voice from the client is forwarded to other members of the module.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReadWrite
Full RX + TX.
ReadOnly
Listen-only — client receives streams but transmissions are dropped.